@@ -4,25 +4,20 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2007-2008                                               *
+ *   copyright (C) 2007-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
-//
-// C++ Implementation: csharpwriter
-//
 #include "csharpwriter.h"
 
 #include "association.h"
 #include "attribute.h"
 #include "classifier.h"
+#include "debug_utils.h"
 #include "folder.h"
 #include "operation.h"
 #include "uml.h"
 #include "umldoc.h"
-#include "umlnamespace.h"
-
-#include <kdebug.h>
 
 #include <QtCore/QRegExp>
 #include <QtCore/QTextStream>
@@ -116,6 +111,9 @@ CSharpWriter::~CSharpWriter()
 {
 }
 
+/**
+ * Get list of predefined data types.
+ */
 QStringList CSharpWriter::defaultDatatypes()
 {
     QStringList l;
@@ -140,6 +138,10 @@ QStringList CSharpWriter::defaultDatatypes()
     return l;
 }
 
+/**
+ * Call this method to generate Php code for a UMLClassifier
+ * @param c the class you want to generate code for.
+ */
 void CSharpWriter::writeClass(UMLClassifier *c)
 {
     if (!c) {
@@ -147,7 +149,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         return;
     }
 
-    QString classname = cleanName(c->getName());
+    QString classname = cleanName(c->name());
     //find an appropriate name for our file
     QString fileName = findFileName(c, ".cs");
     if (fileName.isEmpty()) {
@@ -175,8 +177,8 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         cs << str << m_endl;
     }
 
-    UMLDoc *umldoc = UMLApp::app()->getDocument();
-    UMLFolder *logicalView = umldoc->getRootFolder(Uml::mt_Logical);
+    UMLDoc *umldoc = UMLApp::app()->document();
+    UMLFolder *logicalView = umldoc->rootFolder(Uml::ModelType::Logical);
 
     // write generic includes
     cs << "using System;" << m_endl;
@@ -186,7 +188,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
     //write includes and namespace
 
-    UMLPackage *container = c->getUMLPackage();
+    UMLPackage *container = c->umlPackage();
     if (container == logicalView)
         container = NULL;
 
@@ -199,9 +201,9 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         foreach ( UMLPackage* p , includes ) {
             UMLClassifier *cl = dynamic_cast<UMLClassifier*>(p);
             if (cl)
-                p = cl->getUMLPackage();
+                p = cl->umlPackage();
             if (p != logicalView && m_seenIncludes.indexOf(p) == -1 && p != container) {
-                cs << "using " << p->getFullyQualifiedName(".") << ";" << m_endl;
+                cs << "using " << p->fullyQualifiedName(".") << ";" << m_endl;
                 m_seenIncludes.append(p);
             }
         }
@@ -211,16 +213,16 @@ void CSharpWriter::writeClass(UMLClassifier *c)
     m_container_indent = "";
 
     if (container) {
-        cs << "namespace " << container->getFullyQualifiedName(".") << m_endl;
+        cs << "namespace " << container->fullyQualifiedName(".") << m_endl;
         cs << "{" << m_endl << m_endl;
         m_container_indent = m_indentation;
         m_seenIncludes.append(container);
     }
 
     //Write class Documentation if there is somthing or if force option
-    if (forceDoc() || !c->getDoc().isEmpty()) {
+    if (forceDoc() || !c->doc().isEmpty()) {
         cs << m_container_indent << "/// <summary>" << m_endl;
-        cs << formatDoc(c->getDoc(), m_container_indent + "/// " );
+        cs << formatDoc(c->doc(), m_container_indent + "/// " );
         cs << m_container_indent << "/// </summary>" << m_endl ;
     }
 
@@ -238,7 +240,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
         cs << "interface " << classname;
     } else {
         //check if class is abstract and / or has abstract methods
-        if (c->getAbstract() || c->hasAbstractOps())
+        if (c->isAbstract() || c->hasAbstractOps())
             cs << "abstract ";
 
         cs << "class " << classname << (superclasses.count() > 0 ? " : ":"");
@@ -251,7 +253,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
                     if (supers > 0) {
                         cs << " // AND ";
                     }
-                    cs << cleanName(obj->getName());
+                    cs << cleanName(obj->name());
                     supers++;
                 }
             }
@@ -267,7 +269,7 @@ void CSharpWriter::writeClass(UMLClassifier *c)
                 UMLClassifier *real = (UMLClassifier*)a->getObject(Uml::B);
                 if(real != c) {
                     // write list of realizations
-                    cs << ", " << real->getName();
+                    cs << ", " << real->name();
                 }
 
             }
@@ -302,17 +304,23 @@ void CSharpWriter::writeClass(UMLClassifier *c)
 
     if (container) {
         cs << "}  // end of namespace "
-            << container->getFullyQualifiedName(".") << m_endl << m_endl;
+            << container->fullyQualifiedName(".") << m_endl << m_endl;
     }
 
     //close files and notfiy we are done
     filecs.close();
     emit codeGenerated(c, true);
+    emit showGeneratedFile(filecs.fileName());
 }
 
 ////////////////////////////////////////////////////////////////////////////////////
 //  Helper Methods
 
+/**
+ * Write all operations for a given class.
+ * @param c the concept we are generating code for
+ * @param cs output stream
+ */
 void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
 {
     //Lists to store operations  sorted by scope
@@ -324,7 +332,7 @@ void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
     //sort operations by scope first and see if there are abstract methods
     UMLOperationList opl(c->getOpList());
     foreach (UMLOperation* op,  opl ) {
-        switch (op->getVisibility()) {
+        switch (op->visibility()) {
           case Uml::Visibility::Public:
             oppub.append(op);
             break;
@@ -370,13 +378,18 @@ void CSharpWriter::writeOperations(UMLClassifier *c, QTextStream &cs)
     // write superclasses abstract methods
     UMLClassifierList superclasses = c->getSuperClasses();
 
-    if (!isInterface && !c->getAbstract() && !c->hasAbstractOps()
+    if (!isInterface && !c->isAbstract() && !c->hasAbstractOps()
             && superclasses.count() > 0) {
         writeOverridesRecursive(&superclasses, cs);
     }
 
 }
 
+/**
+ * Write superclasses' abstract methods.
+ * @param superclasses List of superclasses to start recursing on
+ * @param cs output stream
+ */
 void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTextStream &cs)
 {
     // oplist for implemented abstract operations
@@ -387,13 +400,13 @@ void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTex
             // collect abstract ops
             UMLOperationList opl(obj->getOpList());
             foreach (UMLOperation* op, opl ) {
-                if (op->getAbstract()) {
+                if (op->isAbstract()) {
                     opabstract.append(op);
                 }
             }
 
             // write abstract implementations
-            cs << m_endl << m_container_indent << m_indentation << "#region " << obj->getName() << " members" << m_endl << m_endl;
+            cs << m_endl << m_container_indent << m_indentation << "#region " << obj->name() << " members" << m_endl << m_endl;
             writeOperations(opabstract,cs,false,true,true);
             cs << m_container_indent << m_indentation << "#endregion" << m_endl << m_endl;
 
@@ -408,6 +421,12 @@ void CSharpWriter::writeOverridesRecursive(UMLClassifierList *superclasses, QTex
     }
 }
 
+/**
+ * Write realizations of a class and recurse to parent classes.
+ * @param currentClass class to start with
+ * @param realizations realizations of this class
+ * @param cs output stream
+ */
 void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAssociationList *realizations, QTextStream &cs)
 {
     for (UMLAssociationListIt alit(*realizations); alit.hasNext(); ) {
@@ -424,7 +443,7 @@ void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAs
         UMLOperationList opreal = real->getOpList();
 
         // write realizations
-        cs << m_endl << m_container_indent << m_indentation << "#region " << real->getName() << " members" << m_endl << m_endl;
+        cs << m_endl << m_container_indent << m_indentation << "#region " << real->name() << " members" << m_endl << m_endl;
         writeOperations(opreal,cs,false,false,true);
         cs << m_container_indent << m_indentation << "#endregion" << m_endl << m_endl;
 
@@ -436,6 +455,14 @@ void CSharpWriter::writeRealizationsRecursive(UMLClassifier *currentClass, UMLAs
     }
 }
 
+/**
+ * Write a list of class operations.
+ * @param opList the list of operations
+ * @param cs output stream
+ * @param interface indicates if the operation is an interface member
+ * @param isOverride implementation of an inherited abstract function
+ * @param generateErrorStub flag whether an exception should be thrown
+ */
 void CSharpWriter::writeOperations(UMLOperationList opList,
                                  QTextStream &cs, bool isInterface /* = false */,
                                  bool isOverride /* = false */,
@@ -445,25 +472,25 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         UMLAttributeList atl = op->getParmList();
 
         //write method doc if we have doc || if at least one of the params has doc
-        bool writeDoc = forceDoc() || !op->getDoc().isEmpty();
+        bool writeDoc = forceDoc() || !op->doc().isEmpty();
 
         foreach ( UMLAttribute* at, atl ) {
-            writeDoc |= !at->getDoc().isEmpty();
+            writeDoc |= !at->doc().isEmpty();
         }
 
         //write method documentation
         if (writeDoc && !isOverride)
         {
             cs << m_container_indent << m_indentation << "/// <summary>" << m_endl;
-            cs << formatDoc(op->getDoc(), m_container_indent + m_indentation + "/// ");
+            cs << formatDoc(op->doc(), m_container_indent + m_indentation + "/// ");
             cs << m_container_indent << m_indentation << "/// </summary>" << m_endl;
 
             //write parameter documentation
             foreach ( UMLAttribute* at, atl ) {
-                if (forceDoc() || !at->getDoc().isEmpty()) {
-                    cs << m_container_indent << m_indentation << "/// <param name=\"" << cleanName(at->getName()) << "\">";
+                if (forceDoc() || !at->doc().isEmpty()) {
+                    cs << m_container_indent << m_indentation << "/// <param name=\"" << cleanName(at->name()) << "\">";
                     //removing newlines from parameter doc
-                    cs << formatDoc(at->getDoc(), "").replace('\n', ' ').remove('\r').remove(QRegExp(" $"));
+                    cs << formatDoc(at->doc(), "").replace('\n', ' ').remove('\r').remove(QRegExp(" $"));
                     cs << "</param>" << m_endl;
                 }
             }
@@ -481,14 +508,14 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         cs << m_container_indent << m_indentation;
         if (!isInterface) {
             if (!isOverride) {
-                if (op->getAbstract()) cs << "abstract ";
-                cs << op->getVisibility().toString() << " ";
-                if (op->getStatic()) cs << "static ";
+                if (op->isAbstract()) cs << "abstract ";
+                cs << op->visibility().toString() << " ";
+                if (op->isStatic()) cs << "static ";
             }
             else {
                 // method overriding an abstract parent
-                cs << op->getVisibility().toString() << " override ";
-                if (op->getStatic()) cs << "static ";
+                cs << op->visibility().toString() << " override ";
+                if (op->isStatic()) cs << "static ";
             }
         }
 
@@ -503,14 +530,14 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         }
 
         // method name
-        cs << cleanName(op->getName()) << "(";
+        cs << cleanName(op->name()) << "(";
 
         // method parameters
         int i= atl.count();
         int j=0;
         for (UMLAttributeListIt atlIt( atl ); atlIt.hasNext(); ++j) {
             UMLAttribute* at = atlIt.next();
-            cs << makeLocalTypeName(at) << " " << cleanName(at->getName());
+            cs << makeLocalTypeName(at) << " " << cleanName(at->name());
 
             // no initial values in C#
             //<< (!(at->getInitialValue().isEmpty()) ?
@@ -521,7 +548,7 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
         cs << ")";
 
         //FIXME: how to control generation of error stub?
-        if (!isInterface && (!op->getAbstract() || isOverride)) {
+        if (!isInterface && (!op->isAbstract() || isOverride)) {
             cs << m_endl << m_container_indent << m_indentation << "{" << m_endl;
             // write source code of operation else throw not implemented exception
             QString sourceCode = op->getSourceCode();
@@ -543,6 +570,11 @@ void CSharpWriter::writeOperations(UMLOperationList opList,
     }
 }
 
+/**
+ * Write all the attributes of a class.
+ * @param c the class we are generating code for
+ * @param cs output stream
+ */
 void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
 {
     UMLAttributeList  atpub, atprot, atpriv, atdefval;
@@ -553,7 +585,7 @@ void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
     foreach ( UMLAttribute* at, atl ) {
         if (!at->getInitialValue().isEmpty())
             atdefval.append(at);
-        switch (at->getVisibility()) {
+        switch (at->visibility()) {
           case Uml::Visibility::Public:
             atpub.append(at);
             break;
@@ -591,22 +623,33 @@ void CSharpWriter::writeAttributes(UMLClassifier *c, QTextStream &cs)
 
 }
 
+/**
+ * Write a list of class attributes.
+ * @param atList the list of attributes
+ * @param cs output stream
+ */
 void CSharpWriter::writeAttributes(UMLAttributeList &atList, QTextStream &cs)
 {
     foreach (UMLAttribute* at, atList ) {
 
         bool asProperty = true;
-        if (at->getVisibility() == Uml::Visibility::Private) {
+        if (at->visibility() == Uml::Visibility::Private) {
             asProperty = false;
         }
-        writeAttribute(at->getDoc(), at->getVisibility(), at->getStatic(),
-            makeLocalTypeName(at), at->getName(), at->getInitialValue(), asProperty, cs);
+        writeAttribute(at->doc(), at->visibility(), at->isStatic(),
+            makeLocalTypeName(at), at->name(), at->getInitialValue(), asProperty, cs);
 
         cs << m_endl;
     } // end for
     return;
 }
 
+/**
+ * Write attributes from associated objects (compositions, aggregations).
+ * @param associated list of associated objects
+ * @param c currently written class, to see association direction
+ * @param cs output stream
+ */
 void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UMLClassifier *c, QTextStream &cs)
 {
     foreach (UMLAssociation *a,  associated ) {
@@ -620,7 +663,7 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
         }
         // Take name and documentaton from Role, take type name from the referenced object
         QString roleName = cleanName(a->getRoleName(Uml::B));
-        QString typeName = cleanName(o->getName());
+        QString typeName = cleanName(o->name());
         if (roleName.isEmpty()) {
             roleName = QString("UnnamedRoleB_%1").arg(m_unnamedRoles++);
         }
@@ -638,6 +681,17 @@ void CSharpWriter::writeAssociatedAttributes(UMLAssociationList &associated, UML
     }
 }
 
+/**
+ * Write a single attribute to the output stream.
+ * @param doc attribute documentation
+ * @param visibility attribute visibility
+ * @param isStatic static attribute
+ * @param typeName class/type of the attribute
+ * @param name name of the attribute
+ * @param initialValue initial value given to the attribute at declaration
+ * @param asProperty true writes as property (get/set), false writes single line variable
+ * @param cs output stream
+ */
 void CSharpWriter::writeAttribute(const QString& doc,
                                   Uml::Visibility visibility,
                                   bool isStatic,
@@ -691,11 +745,15 @@ void CSharpWriter::writeAttribute(const QString& doc,
     cs << ";" << m_endl << m_endl;
 }
 
+/**
+ * Find the type in used namespaces, if namespace found return short name, complete otherwise.
+ * @param at Operation or Attribute to check type
+ */
 QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 {
-    UMLPackage *p = cl->getType()->getUMLPackage();
+    UMLPackage *p = cl->getType()->umlPackage();
     if (m_seenIncludes.indexOf(p) != -1) {
-        return cl->getType()->getName();
+        return cl->getType()->name();
     }
     else {
         return cl->getTypeName();
@@ -703,12 +761,18 @@ QString CSharpWriter::makeLocalTypeName(UMLClassifierListItem *cl)
 
 }
 
-Uml::Programming_Language CSharpWriter::getLanguage()
+/**
+ * Returns "C#".
+ */
+Uml::ProgrammingLanguage CSharpWriter::language() const
 {
-    return Uml::pl_CSharp;
+    return Uml::ProgrammingLanguage::CSharp;
 }
 
-const QStringList CSharpWriter::reservedKeywords() const
+/**
+ * Get list of reserved keywords.
+ */
+QStringList CSharpWriter::reservedKeywords() const
 {
     static QStringList keywords;
 
