@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2005-2009                                               *
+ *   copyright (C) 2005-2011                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -17,6 +17,7 @@
 #include <QtCore/QStringList>
 
 // fwd decls
+class CodeImpThread;
 class UMLClassifier;
 class UMLOperation;
 class UMLPackage;
@@ -24,7 +25,7 @@ class UMLPackage;
 class CppTree2Uml: public TreeParser
 {
 public:
-    CppTree2Uml( const QString& fileName);
+    explicit CppTree2Uml( const QString& fileName, CodeImpThread* thread = 0);
     virtual ~CppTree2Uml();
 
     //FileDom file() { return m_file; }
@@ -35,6 +36,7 @@ public:
     // declarations
     //virtual void parseDeclaration( DeclarationAST* );  // use parent method
     //virtual void parseLinkageSpecification( LinkageSpecificationAST* );  // use parent method
+    virtual void parseFile( FileAST* ast );
     virtual void parseNamespace( NamespaceAST* );
     //virtual void parseNamespaceAlias( NamespaceAliasAST* );  // use parent method
     //virtual void parseUsing( UsingAST* );  // use parent method
@@ -65,9 +67,6 @@ private:
     QString typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAST* declarator );
     QStringList scopeOfName( NameAST* id, const QStringList& scope );
     QStringList scopeOfDeclarator( DeclaratorAST* d, const QStringList& scope );
-    /**
-     * Flush template parameters pending in m_templateParams to the klass.
-     */
     void flushTemplateParams(UMLClassifier *klass);
 
 private:
@@ -89,6 +88,7 @@ private:
     UMLClassifier* m_currentClass[STACKSIZE+1];  ///< stack
     int m_nsCnt;  ///< stack top for m_currentNamespace
     int m_clsCnt;  ///< stack top for m_currentClass
+    CodeImpThread* m_thread;
 
 private:
     CppTree2Uml( const CppTree2Uml& source );
